<?php

/**
 * @file
 * Administration settings for AddToAny buttons integration.
 */

// Load CSS.
drupal_add_css((drupal_get_path('module', 'addtoany') . '/addtoany.admin.css'));

/**
 * Administration settings form.
 *
 * @return
 *   The completed form definition.
 */
function addtoany_admin_settings() {
  $form = [];

  $form['#attached']['js'] = [
    drupal_get_path('module', 'addtoany') . '/addtoany.admin.js',
  ];

  /* Buttons Settings */
  $form['addtoany_button_settings'] = [
    '#type' => 'fieldset',
    '#title' => t('Buttons'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
    addtoany_buttons_form(),
  ];

  /* Display Settings */
  $form['addtoany_display_settings'] = [
    '#type' => 'fieldset',
    '#title' => t('Display'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
    addtoany_entities_form(),
  ];

  /* Additional Settings */
  $form['addtoany_additional_settings'] = [
    '#type' => 'fieldset',
    '#title' => t('Additional options'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
    addtoany_additional_form(),
  ];

  return system_settings_form($form);
}

/**
 * Implements AddToAny Buttons Form.
 *
 * @return
 *   The buttons configuration form array.
 */
function addtoany_buttons_form() {

  global $base_path;
  $form = [];
  $button_img = '<img src="' . $base_path . drupal_get_path('module', 'addtoany') . '/images/%s" width="%d" height="%d"%s />';

  $button_options = [
    'a2a_svg_32' => sprintf($button_img, 'a2a_32_32.png', 32, 32, ' class="addtoany-round-icon"'),
    'share_save_171_16.png|171|16' => sprintf($button_img, 'share_save_171_16.png', 171, 16, ''),
    'share_save_256_24.png|256|24' => sprintf($button_img, 'share_save_256_24.png', 256, 24, ''),
    'custom' => 'Custom button',
    'text' => 'Text only',
    'none' => 'None',
  ];

  $form['addtoany_button_settings']['addtoany_buttons_size'] = [
    '#type' => 'textfield',
    '#title' => t('Icon size'),
    '#field_suffix' => ' ' . t('pixels'),
    '#default_value' => variable_get('addtoany_buttons_size', '32'),
    '#size' => 10,
    '#maxlength' => 3,
    '#element_validate' => ['element_validate_integer_positive'],
    '#description' => t('AddToAny\'s large SVG icons are mobile ready, pixel perfect on high DPI or retina displays, and revert to PNG in older browsers.'),
    '#required' => TRUE,
  ];
  $form['addtoany_button_settings']['addtoany_service_button_settings'] = [
    '#type' => 'fieldset',
    '#title' => t('Service Buttons'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  ];
  $form['addtoany_button_settings']['addtoany_service_button_settings']['addtoany_additional_html'] = [
    '#type' => 'textarea',
    '#title' => t('Service Buttons HTML code'),
    '#default_value' => variable_get('addtoany_additional_html', ''),
    '#description' => t('You can add HTML code to display customized <a href="https://www.addtoany.com/buttons/customize/drupal/standalone_services" target="_blank">standalone service buttons</a> next to each universal sharing button. For example: <br /> <code>&lt;a class=&quot;a2a_button_facebook&quot;&gt;&lt;/a&gt;<br />&lt;a class=&quot;a2a_button_twitter&quot;&gt;&lt;/a&gt;<br />&lt;a class=&quot;a2a_button_pinterest&quot;&gt;&lt;/a&gt;</code>
    '),
  ];
  $form['addtoany_button_settings']['addtoany_service_button_settings']['addtoany_additional_html_placement'] = [
    '#type' => 'radios',
    '#title' => t('Service Buttons placement'),
    '#default_value' => variable_get('addtoany_additional_html_placement', 'before'),
    '#options' => [
      'before' => t('Before the universal sharing button'),
      'after' => t('After the universal sharing button'),
    ],
  ];
  $form['addtoany_button_settings']['universal_button'] = [
    '#type' => 'fieldset',
    '#title' => t('Universal Button'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
    /* #states workaround in addtoany.admin.js */
  ];
  $form['addtoany_button_settings']['universal_button']['addtoany_image'] = [
    '#type' => 'radios',
    '#title' => t('Button'),
    '#default_value' => variable_get('addtoany_image', 'share_save_171_16.png|171|16'),
    '#attributes' => ['class' => ['addtoany-universal-button-option']],
    '#options' => $button_options,
  ];
  $form['addtoany_button_settings']['universal_button']['addtoany_custom_image'] = [
    '#type' => 'textfield',
    '#title' => t('Custom button URL'),
    '#default_value' => variable_get('addtoany_custom_image', ''),
    '#description' => t('URL to the button image of your choosing. Example: http://example.com/share.png'),
    '#states' => [
      // Show only if custom button is selected.
      'visible' => [
        ':input[name="addtoany_image"]' => ['value' => 'custom'],
      ],
    ],
  ];
  $form['addtoany_button_settings']['universal_button']['addtoany_image_attributes'] = [
    '#type' => 'textfield',
    '#title' => t('Button image HTML attributes'),
    '#default_value' => variable_get('addtoany_image_attributes', 'alt="Share"'),
    '#description' => t('Extra HTML attributes for img tag. Example: alt=""'),
  ];
  $form['addtoany_button_settings']['universal_button']['addtoany_link_text'] = [
    '#type' => 'textfield',
    '#title' => t('Link text'),
    '#default_value' => variable_get('addtoany_link_text', ''),
    '#description' => t('Text for the universal sharing button link. Example: Share'),
  ];

  return $form;
}

/**
 * Implements AddToAny Entities Form.
 *
 * @return
 *   The entities configuration form array.
 */
function addtoany_entities_form() {

  $form = [];
  $entities = entity_get_info();

  foreach ($entities as $entity => $info) {

    $bundles = $info['bundles'];

    $form['addtoany_' . $entity] = [
      '#type' => 'fieldset',
      '#title' => t('!entity', ['!entity' => ucwords($entity)]),
      '#description' => t('Display buttons for <em>!entity</em> entity type.', ['!entity' => $entity]),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
    ];

    $form['addtoany_' . $entity]['addtoany_' . $entity . '_bundles'] = [
      '#type' => 'checkboxes',
      '#title' => t('<em>!entity</em> bundles', ['!entity' => ucwords($entity)]),
      '#description' => t('Select !entity bundles.', ['!entity' => $entity]),
      '#default_value' => variable_get('addtoany_' . $entity . '_bundles', []),
      '#options' => array_combine(array_keys($bundles), array_keys($bundles)),
    ];

    $form['addtoany_' . $entity]['addtoany_' . $entity . '_view_mode'] = [
      '#type' => 'checkboxes',
      '#title' => t('<em>!entity</em> view modes', ['!entity' => ucwords($entity)]),
      '#default_value' => variable_get('addtoany_' . $entity . '_view_mode', []),
      '#options' => array_combine(array_keys($info['view modes']), array_keys($info['view modes'])),
    ];

    $form['addtoany_' . $entity]['addtoany_' . $entity . '_section'] = [
      '#type' => 'radios',
      '#title' => t('Display Section'),
      '#default_value' => variable_get('addtoany_' . $entity . '_section', 'content'),
      '#options' => ['content', 'links'],
      '#description' => t('Select the section in which display buttons.'),
    ];

    $form['addtoany_' . $entity]['addtoany_' . $entity . '_section_weight'] = [
      '#type' => 'weight',
      '#title' => t('Weight'),
      '#default_value' => variable_get('addtoany_' . $entity . '_section_weight', 40),
      '#delta' => 50,
      '#description' => t('<strong>Optional</strong>: <em>Weight</em> value for AddToAny button displayed in <em>Content</em> section'),
      '#states' => [
        // Show the settings if 'bar' has been selected for 'foo'.
        'visible' => [
          ':input[name="addtoany_' . $entity . '_section"]' => ['value' => 0],
        ],
      ],
    ];
  }

  return $form;
}

/**
 * Implements AddToAny Additional Settings Form.
 *
 * @return
 *   The additional configurations form array.
 */
function addtoany_additional_form() {

  $form['addtoany_additional_settings']['addtoany_additional_js'] = [
    '#type' => 'textarea',
    '#title' => t('Additional JavaScript'),
    '#default_value' => variable_get('addtoany_additional_js', ''),
    '#description' => t('You can add special JavaScript code for AddToAny. Advanced users might want to check out AddToAny\'s <a href="https://www.addtoany.com/buttons/api/" target="_blank">JavaScript API</a> and <a href="https://www.addtoany.com/buttons/customize/drupal" target="_blank">documentation</a>.'),
  ];
  $form['addtoany_additional_settings']['addtoany_additional_css'] = [
    '#type' => 'textarea',
    '#title' => t('Additional CSS'),
    '#default_value' => variable_get('addtoany_additional_css', ''),
    '#description' => t('You can add special CSS code for AddToAny. See <a href="https://www.addtoany.com/buttons/customize/drupal" target="_blank">AddToAny documentation</a> for customizations.'),
  ];
  $form['addtoany_additional_settings']['addtoany_no_3p'] = [
    '#type' => 'checkbox',
    '#title' => t('Disable 3rd party cookies'),
    '#default_value' => variable_get('addtoany_no_3p', '0'),
    '#description' => t('Disabling may affect analytics and limit some functionality.'),
  ];

  return $form;

}
